# pyright: reportUnusedImport=false
import struct
from typing import Optional, Self, Sequence
from .. import abcs
from ..core import Request, serialize_bytes_to
_bytes = bytes | bytearray | memoryview
def register_device(*, no_muted: bool, token_type: int, token: str, app_sandbox: bool, secret: _bytes, other_uids: Sequence[int]) -> Request[bool]:
    _buffer = bytearray(b'z\x01\x86\xec')
    flags = (1 if no_muted else 0)
    _buffer += struct.pack('<I', flags)
    _buffer += struct.pack('<i', token_type)
    serialize_bytes_to(_buffer, token.encode('utf-8'))
    _buffer += struct.pack('<I', app_sandbox)
    serialize_bytes_to(_buffer, secret)
    _buffer += struct.pack('<ii', 0x1cb5c415, len(other_uids))
    _buffer += struct.pack(f'<{len(other_uids)}q', *other_uids)
    return Request(b'' + _buffer)
def unregister_device(*, token_type: int, token: str, other_uids: Sequence[int]) -> Request[bool]:
    _buffer = bytearray(b'\x062\rj')
    _buffer += struct.pack('<i', token_type)
    serialize_bytes_to(_buffer, token.encode('utf-8'))
    _buffer += struct.pack('<ii', 0x1cb5c415, len(other_uids))
    _buffer += struct.pack(f'<{len(other_uids)}q', *other_uids)
    return Request(b'' + _buffer)
def update_notify_settings(*, peer: abcs.InputNotifyPeer, settings: abcs.InputPeerNotifySettings) -> Request[bool]:
    _buffer = bytearray(b'\x93[\xbe\x84')
    peer._write_boxed_to(_buffer)
    settings._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def get_notify_settings(*, peer: abcs.InputNotifyPeer) -> Request[abcs.PeerNotifySettings]:
    _buffer = bytearray(b'1\xad\xb3\x12')
    peer._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def reset_notify_settings() -> Request[bool]:
    _buffer = bytearray(b'G\x17~\xdb')
    return Request(b'' + _buffer)
def update_profile(*, first_name: Optional[str], last_name: Optional[str], about: Optional[str]) -> Request[abcs.User]:
    _buffer = bytearray(b'uWQx')
    flags = (0 if first_name is None else 1) | (0 if last_name is None else 2) | (0 if about is None else 4)
    _buffer += struct.pack('<I', flags)
    if first_name is not None:
      serialize_bytes_to(_buffer, first_name.encode('utf-8'))
    if last_name is not None:
      serialize_bytes_to(_buffer, last_name.encode('utf-8'))
    if about is not None:
      serialize_bytes_to(_buffer, about.encode('utf-8'))
    return Request(b'' + _buffer)
def update_status(*, offline: bool) -> Request[bool]:
    _buffer = bytearray(b',V(f')
    _buffer += struct.pack('<I', offline)
    return Request(b'' + _buffer)
def get_wall_papers(*, hash: int) -> Request[abcs.account.WallPapers]:
    _buffer = bytearray(b'6}\x96\x07')
    _buffer += struct.pack('<q', hash)
    return Request(b'' + _buffer)
def report_peer(*, peer: abcs.InputPeer, reason: abcs.ReportReason, message: str) -> Request[bool]:
    _buffer = bytearray(b'\x86=\xba\xc5')
    peer._write_boxed_to(_buffer)
    reason._write_boxed_to(_buffer)
    serialize_bytes_to(_buffer, message.encode('utf-8'))
    return Request(b'' + _buffer)
def check_username(*, username: str) -> Request[bool]:
    _buffer = bytearray(b"l\xd8\x14'")
    serialize_bytes_to(_buffer, username.encode('utf-8'))
    return Request(b'' + _buffer)
def update_username(*, username: str) -> Request[abcs.User]:
    _buffer = bytearray(b'|\xdd\x0b>')
    serialize_bytes_to(_buffer, username.encode('utf-8'))
    return Request(b'' + _buffer)
def get_privacy(*, key: abcs.InputPrivacyKey) -> Request[abcs.account.PrivacyRules]:
    _buffer = bytearray(b'P\xc9\xdb\xda')
    key._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def set_privacy(*, key: abcs.InputPrivacyKey, rules: Sequence[abcs.InputPrivacyRule]) -> Request[abcs.account.PrivacyRules]:
    _buffer = bytearray(b'\xe8\x1c\xf8\xc9')
    key._write_boxed_to(_buffer)
    _buffer += struct.pack('<ii', 0x1cb5c415, len(rules))
    for _t0 in rules:
      _t0._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def delete_account(*, reason: str, password: Optional[abcs.InputCheckPasswordSrp]) -> Request[bool]:
    _buffer = bytearray(b't\xcf\xc0\xa2')
    flags = (0 if password is None else 1)
    _buffer += struct.pack('<I', flags)
    serialize_bytes_to(_buffer, reason.encode('utf-8'))
    if password is not None:
      password._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def get_account_ttl() -> Request[abcs.AccountDaysTtl]:
    _buffer = bytearray(b'\x1dq\xfc\x08')
    return Request(b'' + _buffer)
def set_account_ttl(*, ttl: abcs.AccountDaysTtl) -> Request[bool]:
    _buffer = bytearray(b'^HB$')
    ttl._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def send_change_phone_code(*, phone_number: str, settings: abcs.CodeSettings) -> Request[abcs.auth.SentCode]:
    _buffer = bytearray(b'\xe5JW\x82')
    serialize_bytes_to(_buffer, phone_number.encode('utf-8'))
    settings._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def change_phone(*, phone_number: str, phone_code_hash: str, phone_code: str) -> Request[abcs.User]:
    _buffer = bytearray(b'\xdb.\xc3p')
    serialize_bytes_to(_buffer, phone_number.encode('utf-8'))
    serialize_bytes_to(_buffer, phone_code_hash.encode('utf-8'))
    serialize_bytes_to(_buffer, phone_code.encode('utf-8'))
    return Request(b'' + _buffer)
def update_device_locked(*, period: int) -> Request[bool]:
    _buffer = bytearray(b'25\xdf8')
    _buffer += struct.pack('<i', period)
    return Request(b'' + _buffer)
def get_authorizations() -> Request[abcs.account.Authorizations]:
    _buffer = bytearray(b'X\xc1 \xe3')
    return Request(b'' + _buffer)
def reset_authorization(*, hash: int) -> Request[bool]:
    _buffer = bytearray(b'\xbc\xf3w\xdf')
    _buffer += struct.pack('<q', hash)
    return Request(b'' + _buffer)
def get_password() -> Request[abcs.account.Password]:
    _buffer = bytearray(b'\xf50\x8aT')
    return Request(b'' + _buffer)
def get_password_settings(*, password: abcs.InputCheckPasswordSrp) -> Request[abcs.account.PasswordSettings]:
    _buffer = bytearray(b'\xf9\xea\xd4\x9c')
    password._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def update_password_settings(*, password: abcs.InputCheckPasswordSrp, new_settings: abcs.account.PasswordInputSettings) -> Request[bool]:
    _buffer = bytearray(b'/\x10\x9b\xa5')
    password._write_boxed_to(_buffer)
    new_settings._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def send_confirm_phone_code(*, hash: str, settings: abcs.CodeSettings) -> Request[abcs.auth.SentCode]:
    _buffer = bytearray(b'\x88\xaa?\x1b')
    serialize_bytes_to(_buffer, hash.encode('utf-8'))
    settings._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def confirm_phone(*, phone_code_hash: str, phone_code: str) -> Request[bool]:
    _buffer = bytearray(b'\xc3x!_')
    serialize_bytes_to(_buffer, phone_code_hash.encode('utf-8'))
    serialize_bytes_to(_buffer, phone_code.encode('utf-8'))
    return Request(b'' + _buffer)
def get_tmp_password(*, password: abcs.InputCheckPasswordSrp, period: int) -> Request[abcs.account.TmpPassword]:
    _buffer = bytearray(b'Q\x0b\x9eD')
    password._write_boxed_to(_buffer)
    _buffer += struct.pack('<i', period)
    return Request(b'' + _buffer)
def get_web_authorizations() -> Request[abcs.account.WebAuthorizations]:
    _buffer = bytearray(b'om.\x18')
    return Request(b'' + _buffer)
def reset_web_authorization(*, hash: int) -> Request[bool]:
    _buffer = bytearray(b'\xef\xb9\x01-')
    _buffer += struct.pack('<q', hash)
    return Request(b'' + _buffer)
def reset_web_authorizations() -> Request[bool]:
    _buffer = bytearray(b'\x94%-h')
    return Request(b'' + _buffer)
def get_all_secure_values() -> Request[Sequence[abcs.SecureValue]]:
    _buffer = bytearray(b'}\xbc\x88\xb2')
    return Request(b'' + _buffer)
def get_secure_value(*, types: Sequence[abcs.SecureValueType]) -> Request[Sequence[abcs.SecureValue]]:
    _buffer = bytearray(b'\xc2[fs')
    _buffer += struct.pack('<ii', 0x1cb5c415, len(types))
    for _t0 in types:
      _t0._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def save_secure_value(*, value: abcs.InputSecureValue, secure_secret_id: int) -> Request[abcs.SecureValue]:
    _buffer = bytearray(b'\x1d\xe3\x9f\x89')
    value._write_boxed_to(_buffer)
    _buffer += struct.pack('<q', secure_secret_id)
    return Request(b'' + _buffer)
def delete_secure_value(*, types: Sequence[abcs.SecureValueType]) -> Request[bool]:
    _buffer = bytearray(b'K\xbc\x80\xb8')
    _buffer += struct.pack('<ii', 0x1cb5c415, len(types))
    for _t0 in types:
      _t0._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def get_authorization_form(*, bot_id: int, scope: str, public_key: str) -> Request[abcs.account.AuthorizationForm]:
    _buffer = bytearray(b'zY)\xa9')
    _buffer += struct.pack('<q', bot_id)
    serialize_bytes_to(_buffer, scope.encode('utf-8'))
    serialize_bytes_to(_buffer, public_key.encode('utf-8'))
    return Request(b'' + _buffer)
def accept_authorization(*, bot_id: int, scope: str, public_key: str, value_hashes: Sequence[abcs.SecureValueHash], credentials: abcs.SecureCredentialsEncrypted) -> Request[bool]:
    _buffer = bytearray(b'sL\xed\xf3')
    _buffer += struct.pack('<q', bot_id)
    serialize_bytes_to(_buffer, scope.encode('utf-8'))
    serialize_bytes_to(_buffer, public_key.encode('utf-8'))
    _buffer += struct.pack('<ii', 0x1cb5c415, len(value_hashes))
    for _t0 in value_hashes:
      _t0._write_boxed_to(_buffer)
    credentials._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def send_verify_phone_code(*, phone_number: str, settings: abcs.CodeSettings) -> Request[abcs.auth.SentCode]:
    _buffer = bytearray(b'\xf9V\xa3\xa5')
    serialize_bytes_to(_buffer, phone_number.encode('utf-8'))
    settings._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def verify_phone(*, phone_number: str, phone_code_hash: str, phone_code: str) -> Request[bool]:
    _buffer = bytearray(b'\xf6\xa7\xd3M')
    serialize_bytes_to(_buffer, phone_number.encode('utf-8'))
    serialize_bytes_to(_buffer, phone_code_hash.encode('utf-8'))
    serialize_bytes_to(_buffer, phone_code.encode('utf-8'))
    return Request(b'' + _buffer)
def send_verify_email_code(*, purpose: abcs.EmailVerifyPurpose, email: str) -> Request[abcs.account.SentEmailCode]:
    _buffer = bytearray(b'\xbb7\xe0\x98')
    purpose._write_boxed_to(_buffer)
    serialize_bytes_to(_buffer, email.encode('utf-8'))
    return Request(b'' + _buffer)
def verify_email(*, purpose: abcs.EmailVerifyPurpose, verification: abcs.EmailVerification) -> Request[abcs.account.EmailVerified]:
    _buffer = bytearray(b'\xcf\xa4-\x03')
    purpose._write_boxed_to(_buffer)
    verification._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def init_takeout_session(*, contacts: bool, message_users: bool, message_chats: bool, message_megagroups: bool, message_channels: bool, files: bool, file_max_size: Optional[int]) -> Request[abcs.account.Takeout]:
    _buffer = bytearray(b'\xb0\xea\xf3\x8e')
    flags = (1 if contacts else 0) | (2 if message_users else 0) | (4 if message_chats else 0) | (8 if message_megagroups else 0) | (16 if message_channels else 0) | (32 if files else 0) | (0 if file_max_size is None else 32)
    _buffer += struct.pack('<I', flags)
    if file_max_size is not None:
      _buffer += struct.pack(f'<q', file_max_size)
    return Request(b'' + _buffer)
def finish_takeout_session(*, success: bool) -> Request[bool]:
    _buffer = bytearray(b'\xeeR&\x1d')
    flags = (1 if success else 0)
    _buffer += struct.pack('<I', flags)
    return Request(b'' + _buffer)
def confirm_password_email(*, code: str) -> Request[bool]:
    _buffer = bytearray(b' \x19\xdf\x8f')
    serialize_bytes_to(_buffer, code.encode('utf-8'))
    return Request(b'' + _buffer)
def resend_password_email() -> Request[bool]:
    _buffer = bytearray(b'\x15*\x7fz')
    return Request(b'' + _buffer)
def cancel_password_email() -> Request[bool]:
    _buffer = bytearray(b'\xb6\xd5\xcb\xc1')
    return Request(b'' + _buffer)
def get_contact_sign_up_notification() -> Request[bool]:
    _buffer = bytearray(b'(\xc7\x07\x9f')
    return Request(b'' + _buffer)
def set_contact_sign_up_notification(*, silent: bool) -> Request[bool]:
    _buffer = bytearray(b'a?\xf4\xcf')
    _buffer += struct.pack('<I', silent)
    return Request(b'' + _buffer)
def get_notify_exceptions(*, compare_sound: bool, compare_stories: bool, peer: Optional[abcs.InputNotifyPeer]) -> Request[abcs.Updates]:
    _buffer = bytearray(b'ytWS')
    flags = (2 if compare_sound else 0) | (4 if compare_stories else 0) | (0 if peer is None else 1)
    _buffer += struct.pack('<I', flags)
    if peer is not None:
      peer._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def get_wall_paper(*, wallpaper: abcs.InputWallPaper) -> Request[abcs.WallPaper]:
    _buffer = bytearray(b'\xea\xdb\x8d\xfc')
    wallpaper._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def upload_wall_paper(*, for_chat: bool, file: abcs.InputFile, mime_type: str, settings: abcs.WallPaperSettings) -> Request[abcs.WallPaper]:
    _buffer = bytearray(b'\x03\x8f\x9a\xe3')
    flags = (1 if for_chat else 0)
    _buffer += struct.pack('<I', flags)
    file._write_boxed_to(_buffer)
    serialize_bytes_to(_buffer, mime_type.encode('utf-8'))
    settings._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def save_wall_paper(*, wallpaper: abcs.InputWallPaper, unsave: bool, settings: abcs.WallPaperSettings) -> Request[bool]:
    _buffer = bytearray(b'7[Zl')
    wallpaper._write_boxed_to(_buffer)
    _buffer += struct.pack('<I', unsave)
    settings._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def install_wall_paper(*, wallpaper: abcs.InputWallPaper, settings: abcs.WallPaperSettings) -> Request[bool]:
    _buffer = bytearray(b'iW\xed\xfe')
    wallpaper._write_boxed_to(_buffer)
    settings._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def reset_wall_papers() -> Request[bool]:
    _buffer = bytearray(b'\x04\x98;\xbb')
    return Request(b'' + _buffer)
def get_auto_download_settings() -> Request[abcs.account.AutoDownloadSettings]:
    _buffer = bytearray(b'?\x0b\xdaV')
    return Request(b'' + _buffer)
def save_auto_download_settings(*, low: bool, high: bool, settings: abcs.AutoDownloadSettings) -> Request[bool]:
    _buffer = bytearray(b'3b\xf3v')
    flags = (1 if low else 0) | (2 if high else 0)
    _buffer += struct.pack('<I', flags)
    settings._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def upload_theme(*, file: abcs.InputFile, thumb: Optional[abcs.InputFile], file_name: str, mime_type: str) -> Request[abcs.Document]:
    _buffer = bytearray(b'3\xb3=\x1c')
    flags = (0 if thumb is None else 1)
    _buffer += struct.pack('<I', flags)
    file._write_boxed_to(_buffer)
    if thumb is not None:
      thumb._write_boxed_to(_buffer)
    serialize_bytes_to(_buffer, file_name.encode('utf-8'))
    serialize_bytes_to(_buffer, mime_type.encode('utf-8'))
    return Request(b'' + _buffer)
def create_theme(*, slug: str, title: str, document: Optional[abcs.InputDocument], settings: Optional[Sequence[abcs.InputThemeSettings]]) -> Request[abcs.Theme]:
    _buffer = bytearray(b'\x00D.e')
    flags = (0 if document is None else 4) | (0 if settings is None else 8)
    _buffer += struct.pack('<I', flags)
    serialize_bytes_to(_buffer, slug.encode('utf-8'))
    serialize_bytes_to(_buffer, title.encode('utf-8'))
    if document is not None:
      document._write_boxed_to(_buffer)
    if settings is not None:
      _buffer += struct.pack('<ii', 0x1cb5c415, len(settings))
      for _t0 in settings:
        _t0._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def update_theme(*, format: str, theme: abcs.InputTheme, slug: Optional[str], title: Optional[str], document: Optional[abcs.InputDocument], settings: Optional[Sequence[abcs.InputThemeSettings]]) -> Request[abcs.Theme]:
    _buffer = bytearray(b'\xcc\x0c\xf4+')
    flags = (0 if slug is None else 1) | (0 if title is None else 2) | (0 if document is None else 4) | (0 if settings is None else 8)
    _buffer += struct.pack('<I', flags)
    serialize_bytes_to(_buffer, format.encode('utf-8'))
    theme._write_boxed_to(_buffer)
    if slug is not None:
      serialize_bytes_to(_buffer, slug.encode('utf-8'))
    if title is not None:
      serialize_bytes_to(_buffer, title.encode('utf-8'))
    if document is not None:
      document._write_boxed_to(_buffer)
    if settings is not None:
      _buffer += struct.pack('<ii', 0x1cb5c415, len(settings))
      for _t0 in settings:
        _t0._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def save_theme(*, theme: abcs.InputTheme, unsave: bool) -> Request[bool]:
    _buffer = bytearray(b'l\x10W\xf2')
    theme._write_boxed_to(_buffer)
    _buffer += struct.pack('<I', unsave)
    return Request(b'' + _buffer)
def install_theme(*, dark: bool, theme: Optional[abcs.InputTheme], format: Optional[str], base_theme: Optional[abcs.BaseTheme]) -> Request[bool]:
    _buffer = bytearray(b";\xbb'\xc7")
    flags = (1 if dark else 0) | (0 if theme is None else 2) | (0 if format is None else 4) | (0 if base_theme is None else 8)
    _buffer += struct.pack('<I', flags)
    if theme is not None:
      theme._write_boxed_to(_buffer)
    if format is not None:
      serialize_bytes_to(_buffer, format.encode('utf-8'))
    if base_theme is not None:
      base_theme._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def get_theme(*, format: str, theme: abcs.InputTheme) -> Request[abcs.Theme]:
    _buffer = bytearray(b'\xeciX:')
    serialize_bytes_to(_buffer, format.encode('utf-8'))
    theme._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def get_themes(*, format: str, hash: int) -> Request[abcs.account.Themes]:
    _buffer = bytearray(b'X\xe4\x06r')
    serialize_bytes_to(_buffer, format.encode('utf-8'))
    _buffer += struct.pack('<q', hash)
    return Request(b'' + _buffer)
def set_content_settings(*, sensitive_enabled: bool) -> Request[bool]:
    _buffer = bytearray(b'k\xb1t\xb5')
    flags = (1 if sensitive_enabled else 0)
    _buffer += struct.pack('<I', flags)
    return Request(b'' + _buffer)
def get_content_settings() -> Request[abcs.account.ContentSettings]:
    _buffer = bytearray(b'\xaeM\x9b\x8b')
    return Request(b'' + _buffer)
def get_multi_wall_papers(*, wallpapers: Sequence[abcs.InputWallPaper]) -> Request[Sequence[abcs.WallPaper]]:
    _buffer = bytearray(b'\xdcq\xade')
    _buffer += struct.pack('<ii', 0x1cb5c415, len(wallpapers))
    for _t0 in wallpapers:
      _t0._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def get_global_privacy_settings() -> Request[abcs.GlobalPrivacySettings]:
    _buffer = bytearray(b'\xf6L+\xeb')
    return Request(b'' + _buffer)
def set_global_privacy_settings(*, settings: abcs.GlobalPrivacySettings) -> Request[abcs.GlobalPrivacySettings]:
    _buffer = bytearray(b'\xc2\xaa\xda\x1e')
    settings._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def report_profile_photo(*, peer: abcs.InputPeer, photo_id: abcs.InputPhoto, reason: abcs.ReportReason, message: str) -> Request[bool]:
    _buffer = bytearray(b'\xf5\xc6\x8c\xfa')
    peer._write_boxed_to(_buffer)
    photo_id._write_boxed_to(_buffer)
    reason._write_boxed_to(_buffer)
    serialize_bytes_to(_buffer, message.encode('utf-8'))
    return Request(b'' + _buffer)
def reset_password() -> Request[abcs.account.ResetPasswordResult]:
    _buffer = bytearray(b'\x1b\xce\x08\x93')
    return Request(b'' + _buffer)
def decline_password_reset() -> Request[bool]:
    _buffer = bytearray(b'\xf6\t\x94L')
    return Request(b'' + _buffer)
def get_chat_themes(*, hash: int) -> Request[abcs.account.Themes]:
    _buffer = bytearray(b'\x89\xde8\xd6')
    _buffer += struct.pack('<q', hash)
    return Request(b'' + _buffer)
def set_authorization_ttl(*, authorization_ttl_days: int) -> Request[bool]:
    _buffer = bytearray(b'\xa0\x9a\x89\xbf')
    _buffer += struct.pack('<i', authorization_ttl_days)
    return Request(b'' + _buffer)
def change_authorization_settings(*, confirmed: bool, hash: int, encrypted_requests_disabled: Optional[bool], call_requests_disabled: Optional[bool]) -> Request[bool]:
    _buffer = bytearray(b'b\x84\xf4@')
    flags = (8 if confirmed else 0) | (0 if encrypted_requests_disabled is None else 1) | (0 if call_requests_disabled is None else 2)
    _buffer += struct.pack('<I', flags)
    _buffer += struct.pack('<q', hash)
    if encrypted_requests_disabled is not None:
      _buffer += struct.pack(f'<I', (0x997275b5 if encrypted_requests_disabled else 0xbc799737))
    if call_requests_disabled is not None:
      _buffer += struct.pack(f'<I', (0x997275b5 if call_requests_disabled else 0xbc799737))
    return Request(b'' + _buffer)
def get_saved_ringtones(*, hash: int) -> Request[abcs.account.SavedRingtones]:
    _buffer = bytearray(b'\x88"\x90\xe1')
    _buffer += struct.pack('<q', hash)
    return Request(b'' + _buffer)
def save_ringtone(*, id: abcs.InputDocument, unsave: bool) -> Request[abcs.account.SavedRingtone]:
    _buffer = bytearray(b'\x03[\xea=')
    id._write_boxed_to(_buffer)
    _buffer += struct.pack('<I', unsave)
    return Request(b'' + _buffer)
def upload_ringtone(*, file: abcs.InputFile, file_name: str, mime_type: str) -> Request[abcs.Document]:
    _buffer = bytearray(b'\xa2\x83\x1a\x83')
    file._write_boxed_to(_buffer)
    serialize_bytes_to(_buffer, file_name.encode('utf-8'))
    serialize_bytes_to(_buffer, mime_type.encode('utf-8'))
    return Request(b'' + _buffer)
def update_emoji_status(*, emoji_status: abcs.EmojiStatus) -> Request[bool]:
    _buffer = bytearray(b'k\xde\xd3\xfb')
    emoji_status._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def get_default_emoji_statuses(*, hash: int) -> Request[abcs.account.EmojiStatuses]:
    _buffer = bytearray(b'\x863u\xd6')
    _buffer += struct.pack('<q', hash)
    return Request(b'' + _buffer)
def get_recent_emoji_statuses(*, hash: int) -> Request[abcs.account.EmojiStatuses]:
    _buffer = bytearray(b'\x05\x81W\x0f')
    _buffer += struct.pack('<q', hash)
    return Request(b'' + _buffer)
def clear_recent_emoji_statuses() -> Request[bool]:
    _buffer = bytearray(b'\xae\x1a \x18')
    return Request(b'' + _buffer)
def reorder_usernames(*, order: Sequence[str]) -> Request[bool]:
    _buffer = bytearray(b'\xab\x0eP\xef')
    _buffer += struct.pack('<ii', 0x1cb5c415, len(order))
    for _t0 in order:
      serialize_bytes_to(_buffer, _t0.encode('utf-8'))
    return Request(b'' + _buffer)
def toggle_username(*, username: str, active: bool) -> Request[bool]:
    _buffer = bytearray(b'v\xb3\xd6X')
    serialize_bytes_to(_buffer, username.encode('utf-8'))
    _buffer += struct.pack('<I', active)
    return Request(b'' + _buffer)
def get_default_profile_photo_emojis(*, hash: int) -> Request[abcs.EmojiList]:
    _buffer = bytearray(b'(\x03u\xe2')
    _buffer += struct.pack('<q', hash)
    return Request(b'' + _buffer)
def get_default_group_photo_emojis(*, hash: int) -> Request[abcs.EmojiList]:
    _buffer = bytearray(b'\xae`X\x91')
    _buffer += struct.pack('<q', hash)
    return Request(b'' + _buffer)
def get_auto_save_settings() -> Request[abcs.account.AutoSaveSettings]:
    _buffer = bytearray(b'\xda\xbc\xcb\xad')
    return Request(b'' + _buffer)
def save_auto_save_settings(*, users: bool, chats: bool, broadcasts: bool, peer: Optional[abcs.InputPeer], settings: abcs.AutoSaveSettings) -> Request[bool]:
    _buffer = bytearray(b'a\x83\x9b\xd6')
    flags = (1 if users else 0) | (2 if chats else 0) | (4 if broadcasts else 0) | (0 if peer is None else 8)
    _buffer += struct.pack('<I', flags)
    if peer is not None:
      peer._write_boxed_to(_buffer)
    settings._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def delete_auto_save_exceptions() -> Request[bool]:
    _buffer = bytearray(b' \x00\xbcS')
    return Request(b'' + _buffer)
def invalidate_sign_in_codes(*, codes: Sequence[str]) -> Request[bool]:
    _buffer = bytearray(b'\xba\xe8\x8a\xca')
    _buffer += struct.pack('<ii', 0x1cb5c415, len(codes))
    for _t0 in codes:
      serialize_bytes_to(_buffer, _t0.encode('utf-8'))
    return Request(b'' + _buffer)
